import React, {Component} from 'react';
import styled from 'styled-components';
import Advanced from './Advanced';
import * as functions from '../src/functions';

import Less from "less/lib/less/";

const App = styled.div`
	color: @text;
`;

const Title = styled.h1`
	font-size: 1.5em;
	color: @highlight;
	b {
		color: darken(@highlight, 20%);
	}
`;

const Wrapper = styled.section`
	text-align: center;
	padding: 4em;
	background-color: @background;
`;

const Button = styled.a`
    display: inline-block;
	cursor: pointer;
	cursor: if(@disabled, not-allowed);
	color: white;
	padding: 10px 30px;
	border: 1px solid rgba(0, 0, 0, 0.21);
	border-bottom: 4px solid rgba(0, 0, 0, 0.21);
	border-radius: 4px;
	text-shadow: 0 1px 0 rgba(0, 0, 0, 0.15);
	background: linear-gradient(@highlight 0%, darken(@highlight, 5%) 100%);
	&:active {
		background: darken(@highlight, 10%);
	}
`;

export default class extends Component {
    state = {open: true};
    onClick = e => this.setState({open: !this.state.open});

    componentDidMount() {
        let str = `
        min: min(5, 10);
        min: min(3px, 42px, 2px, 16px);
        min: min(@a, @b, @c);
        `;
        const less = new Less();

        less.tree.Variable = require('../src/tree/Variable').default;
        less.tree.Condition = require('../src/tree/Condition').default;

        less.functions.functionRegistry.addMultiple(functions);

        console.log("less", less);
        less.PluginLoader = class PluginLoader {
        };
        let root, imports, options;
        less.parse(str, {}, (e, _root, _imports, _options) => {
            if (e) {
                console.error(e);
            }
            root = _root;
            imports = _imports;
            options = _options;
        });
        console.log("root", root);

        // Disables the validation: Properties must be inside selector blocks. They cannot be in the root
        root.firstRoot = false;

        const parseTree = new less.ParseTree(root, imports);
        const result = parseTree.toCSS(options);
        console.log("result:", result.css);
    }

    render() {
        return <App>
            <Wrapper>
                <Title>
                    Hello World, this is my first styled <b>component</b>!
                </Title>
                <Title highlight="#9C5068">
                    Hello World, this is my first styled <b>component</b>!
                </Title>
                <Button onClick={this.onClick}>Click me</Button> <Button highlight="#00A65A" onClick={this.onClick}>Or me</Button> <Button disabled>But not me</Button>
                {this.state.open && <Advanced/>}
            </Wrapper>
        </App>
    }
}